@@ -1,6 +1,5 @@
 import importlib
 
-import hdwallets
 from mnemonic import Mnemonic
 from mospy.utils import privkey_to_address
 from mospy.utils import privkey_to_pubkey
@@ -28,6 +27,7 @@ class Account:
         hrp (str): Address Prefix
         address_index (int): Address index to get sub accounts for seed phrases (doesn't work when using a private key)
         protobuf (str): Define which protobuf files to use. Cosmos, Evmos and Osmosis are built in and otherwise pass the raw package name (cosmospy-protobuf)
+        eth (bool): Etermint compatibility mpde. If set to true the addresses and signatures will match the ethereum standard. Defaults to false to match the Cosmos standard.
     """
 
     address: str
